@@ -70,20 +70,20 @@ set.seed(9292)
 
 
 #Estimate the parameters by Gibbs Sampling (Time difference of 20.28974 secs)
-start.time <- Sys.time()
+#start.time <- Sys.time()
 
-res<-rlda.multinomial(as.data.frame(FIA), 4, beta, NA, 100,  FALSE, TRUE)
+#res<-rlda.multinomial(as.data.frame(FIA), 4, beta, NA, 100,  FALSE, TRUE)
 #res<-lda_multinomial_burn(FIA, 4, beta, NA, 1000, 50,  FALSE, TRUE)
 
-end.time <- Sys.time()
-time.taken <- end.time - start.time
-time.taken
+#end.time <- Sys.time()
+#time.taken <- end.time - start.time
+#time.taken
 
-plot(res)
+#plot(res)
 
 
 
 #Get the logLikelihood with Priors
-logLikeli<-res$logLikelihood
+#logLikeli<-res$logLikelihood
 
 
